==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/viewer/l10n/ug.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "كۆرگۈچى",
    "Simple file viewer with slideshow for media" : "مېدىيا ئۈچۈن تام تەسۋىر بىلەن ئاددىي ھۆججەت كۆرگۈچى",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "كىنودىكىگە ئوخشاش ئەڭ يېڭى بايراملىق سۈرەت ۋە سىنلىرىڭىزنى كۆرسىتىڭ ، Nextcloud دىن بىۋاسىتە ئەڭ يېڭى رومانىڭىزنى كۆرۈڭ ، ياقتۇرىدىغان ھۆججەتلىرىڭىزنى بىۋاسىتە كۆرۈپ بېقىش ئارقىلىق توپلىمىڭىزدىكى ئەڭ ياخشى سوۋغاتنى تاللاڭ!",
    "Your browser does not support audio." : "توركۆرگۈڭىز ئاۋازنى قوللىمايدۇ.",
    "Error loading {name}" : "يۈكلەشتە خاتالىق {name}",
    "Image saved" : "رەسىم ساقلاندى",
    "Error saving image" : "رەسىمنى ساقلاشتا خاتالىق",
    "Unsaved changes" : "ساقلانمىغان ئۆزگەرتىش",
    "Drop changes" : "ئۆزگەرتىشلەرنى تاشلاڭ",
    "Play the live photo" : "نەق مەيدان سۈرىتىنى قويۇڭ",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "توركۆرگۈڭىز سىنلارنى قوللىمايدۇ.",
    "This file no longer exists" : "بۇ ھۆججەت مەۋجۇت ئەمەس",
    "There is no plugin available to display this file type" : "بۇ ھۆججەت تىپىنى كۆرسىتىدىغان قىستۇرما يوق",
    "Edit" : "تەھرىر",
    "Exit full screen" : "تولۇق ئېكراندىن چىقىڭ",
    "Full screen" : "تولۇق ئېكران",
    "Open sidebar" : "يان بالداقنى ئېچىڭ",
    "Download" : "چۈشۈر",
    "Delete" : "ئۆچۈر",
    "View" : "كۆرۈش",
    "Name" : "ئاتى",
    "Save" : "ساقلا",
    "Save as" : "ساقلاڭ",
    "Back" : "قايتىش",
    "Loading …" : "Loading…",
    "Reset" : "ئەسلىگە قايتۇرۇش",
    "All changes will be lost." : "بارلىق ئۆزگىرىشلەر يوقىلىدۇ.",
    "Are you sure you want to continue?" : "داۋاملاشتۇرۇشنى خالامسىز؟",
    "Cancel" : "ۋاز كەچ",
    "Apply" : "ئىلتىماس قىلىڭ",
    "Warning" : "ئاگاھلاندۇرۇش",
    "Confirm" : "جەزملەشتۈرۈڭ",
    "Discard changes" : "ئۆزگەرتىشلەرنى ئەمەلدىن قالدۇرۇڭ",
    "Undo" : "ئەمەلدىن قالدۇرۇش",
    "Redo" : "Redo",
    "Show original image" : "ئەسلى رەسىمنى كۆرسەت",
    "Zoom in" : "چوڭايتىش",
    "Zoom out" : "چوڭايتىڭ",
    "Toggle zoom menu" : "كىچىكلىتىش تىزىملىكى",
    "Adjust" : "تەڭشەش",
    "Fine-tune" : "Fine-tune",
    "Filters" : "سۈزگۈچ",
    "Watermark" : "Watermark",
    "Draw" : "سىزىش",
    "Resize" : "رازمېرى",
    "Image name" : "رەسىم ئىسمى",
    "Invalid image." : "ئىناۋەتسىز رەسىم.",
    "Error while uploading the image." : "رەسىمنى يۈكلەۋاتقاندا خاتالىق.",
    "are not images" : "رەسىم ئەمەس",
    "is not an image" : "رەسىم ئەمەس",
    "to be uploaded" : "يوللاش",
    "Crop" : "Crop",
    "Original" : "ئەسلى",
    "Custom" : "Custom",
    "Square" : "مەيدان",
    "Landscape" : "مەنزىرە",
    "Portrait" : "Portrait",
    "Ellipse" : "Ellipse",
    "Classic TV" : "كىلاسسىك تېلېۋىزور",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "يا ئوق",
    "Blur" : "Blur",
    "Brightness" : "Brightness",
    "Contrast" : "سېلىشتۇرما",
    "Un-flip X" : "Un-flip X.",
    "Flip X" : "Flip X.",
    "Un-flip Y" : "Un-flip Y.",
    "Flip Y" : "Flip Y.",
    "HSV" : "HSV",
    "Hue" : "Hue",
    "Saturation" : "Saturation",
    "Value" : "قىممەت",
    "Image" : "رەسىم",
    "Importing …" : "Importing…",
    "+ Add image" : "+ رەسىم قوشۇڭ",
    "Upload image" : "رەسىم يوللاش",
    "From gallery" : "رەسىم ئامبىرىدىن",
    "Line" : "Line",
    "Pen" : "قەلەم",
    "Polygon" : "كۆپ گۈللۈك",
    "Sides" : "يان تەرەپ",
    "Rectangle" : "تىك تۆت بۇلۇڭ",
    "Corner Radius" : "Corner Radius",
    "Width in pixels" : "پىكسېلنىڭ كەڭلىكى",
    "Height in pixels" : "پېكسىل ئېگىزلىكى",
    "Toggle ratio lock" : "نىسبىتىنى قۇلۇپلاش",
    "Reset to original image size" : "ئەسلى رەسىم چوڭلۇقىغا قايتۇرۇڭ",
    "Rotate" : "ئايلاندۇرۇش",
    "Text" : "تېكىست",
    "Text spacing" : "تېكىست ئارىلىقى",
    "Text alignment" : "تېكىستنى توغرىلاش",
    "Font family" : "خەت نۇسخىسى ئائىلىسى",
    "Size" : "چوڭلۇقى",
    "Letter spacing" : "خەت ئارىلىقى",
    "Line height" : "سىزىق ئېگىزلىكى",
    "Warmth" : "قىزغىن",
    "+ Add watermark" : "+ سۇ بەلگىسى قوشۇڭ",
    "+ Add text watermark" : "+ تېكىست سۇ بەلگىسىنى قوشۇڭ",
    "Choose watermark type" : "سۇ بەلگىسى تۈرىنى تاللاڭ",
    "Upload watermark" : "سۇ بەلگىسىنى يۈكلەڭ",
    "Add as text" : "تېكىست سۈپىتىدە قوشۇڭ",
    "Padding" : "Padding",
    "Paddings" : "Paddings",
    "Shadow" : "سايە",
    "Horizontal" : "توغرىسىغا",
    "Vertical" : "ۋېرتىكال",
    "Opacity" : "Opacity",
    "Transparency" : "Transparency",
    "Position" : "ئورنى",
    "Stroke" : "سەكتە",
    "Save image as" : "رەسىمنى ساقلاڭ",
    "Extension" : "كېڭەيتىش",
    "Format" : "فورماتى",
    "Name is required." : "ئىسىم تەلەپ قىلىنىدۇ.",
    "Quality" : "سۈپەت",
    "Saved image size (width x height)" : "ساقلانغان رەسىم چوڭلۇقى (كەڭلىكى x ئېگىزلىكى)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "شۇنىڭغا دىققەت قىلىڭكى ، تاللانغان زىرائەت رايونى قوللىنىلغان ئۆلچەمدىن تۆۋەن بولۇپ ، سۈپەتنىڭ تۆۋەنلىشىنى كەلتۈرۈپ چىقىرىشى مۇمكىن",
    "Actual size (100%)" : "ئەمەلىي چوڭلۇقى (%100)",
    "Fit size" : "ماس كېلىدىغان چوڭلۇقى",
    "Select image to add …" : "قوشۇش ئۈچۈن رەسىم تاللاڭ…",
    "Failed to load image." : "رەسىم يۈكلەنمىدى.",
    "Menu" : "تىزىملىك",
    "Width" : "كەڭلىك",
    "Height" : "ئېگىزلىكى",
    "No preview available for this crop item" : "بۇ زىرائەت تۈرىگە ئالدىن كۆزىتىش يوق"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/viewer/l10n/ug.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "كۆرگۈچى",
    "Simple file viewer with slideshow for media" : "مېدىيا ئۈچۈن تام تەسۋىر بىلەن ئاددىي ھۆججەت كۆرگۈچى",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "كىنودىكىگە ئوخشاش ئەڭ يېڭى بايراملىق سۈرەت ۋە سىنلىرىڭىزنى كۆرسىتىڭ ، Nextcloud دىن بىۋاسىتە ئەڭ يېڭى رومانىڭىزنى كۆرۈڭ ، ياقتۇرىدىغان ھۆججەتلىرىڭىزنى بىۋاسىتە كۆرۈپ بېقىش ئارقىلىق توپلىمىڭىزدىكى ئەڭ ياخشى سوۋغاتنى تاللاڭ!",
    "Your browser does not support audio." : "توركۆرگۈڭىز ئاۋازنى قوللىمايدۇ.",
    "Error loading {name}" : "يۈكلەشتە خاتالىق {name}",
    "You are about to overwrite the original file. Are you sure you want to continue?" : "سىز ئەسلىي ھۆججەتنى ئۆزگەرتىۋاتىسىز. سىز داملاشتۇرماقچىمۇ؟",
    "A file with this name already exists. Do you want to overwrite it?" : "بۇ نامدىكى ھۆججەت مەۋجۇت. سىز ئۇنى ئۈستىلەپ يازماقچىمۇ؟",
    "Confirm overwrite" : "ئۆزگەرتىشنى جەزىملە",
    "Cancel" : "ۋاز كەچ",
    "Overwrite" : "ئۆزگەرت",
    "An error occurred while trying to confirm the file overwrite." : "ھۆججەتنى ئۆزگەرتىشنى جەزىملەشتۈرۋاتقاندا خاتالىق كۆرۈلدى.",
    "Image saved" : "رەسىم ساقلاندى",
    "Error saving image" : "رەسىمنى ساقلاشتا خاتالىق",
    "Play the live photo" : "نەق مەيدان سۈرىتىنى قويۇڭ",
    "LIVE" : "نەق مەيدان",
    "Your browser does not support videos." : "توركۆرگۈڭىز سىنلارنى قوللىمايدۇ.",
    "This file no longer exists" : "بۇ ھۆججەت مەۋجۇت ئەمەس",
    "There is no plugin available to display this file type" : "بۇ ھۆججەت تىپىنى كۆرسىتىدىغان قىستۇرما يوق",
    "Failed to save file before download" : "چۈشۈرۈشتىن بۇرۇن ھۆججەتنى ساقلاش مەغلۇپ بولدى",
    "Edit" : "تەھرىر",
    "Exit full screen" : "تولۇق ئېكراندىن چىقىڭ",
    "Full screen" : "تولۇق ئېكران",
    "Open sidebar" : "يان بالداقنى ئېچىڭ",
    "Download" : "چۈشۈر",
    "Delete" : "ئۆچۈر",
    "View" : "كۆرۈش",
    "Name" : "ئاتى",
    "Save" : "ساقلا",
    "Save as" : "ساقلاڭ",
    "Back" : "قايتىش",
    "Loading …" : "يۈكلەۋاتىدۇ…",
    "Reset" : "ئەسلىگە قايتۇرۇش",
    "All changes will be lost." : "بارلىق ئۆزگىرىشلەر يوقىلىدۇ.",
    "Are you sure you want to continue?" : "داۋاملاشتۇرۇشنى خالامسىز؟",
    "Apply" : "ئىلتىماس قىلىڭ",
    "Warning" : "ئاگاھلاندۇرۇش",
    "Confirm" : "جەزملەشتۈرۈڭ",
    "Discard changes" : "ئۆزگەرتىشلەرنى ئەمەلدىن قالدۇرۇڭ",
    "Undo" : "ئەمەلدىن قالدۇرۇش",
    "Redo" : "قايتىلا",
    "Show original image" : "ئەسلى رەسىمنى كۆرسەت",
    "Zoom in" : "چوڭايتىش",
    "Zoom out" : "چوڭايتىڭ",
    "Toggle zoom menu" : "كىچىكلىتىش تىزىملىكى",
    "Adjust" : "تەڭشەش",
    "Fine-tune" : "ئوبدان تەڭشە",
    "Filters" : "سۈزگۈچ",
    "Watermark" : "بەلگە",
    "Draw" : "سىزىش",
    "Resize" : "رازمېرى",
    "Image name" : "رەسىم ئىسمى",
    "Invalid image." : "ئىناۋەتسىز رەسىم.",
    "Error while uploading the image." : "رەسىمنى يۈكلەۋاتقاندا خاتالىق.",
    "are not images" : "رەسىم ئەمەس",
    "is not an image" : "رەسىم ئەمەس",
    "to be uploaded" : "يوللاش",
    "Crop" : "كەس",
    "Original" : "ئەسلى",
    "Custom" : "ئۆزگەرتمە",
    "Square" : "مەيدان",
    "Landscape" : "مەنزىرە",
    "Portrait" : "پورتىرىت",
    "Ellipse" : "ئىللىپىس",
    "Classic TV" : "كىلاسسىك تېلېۋىزور",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "يا ئوق",
    "Blur" : "تۇتۇقلا",
    "Brightness" : "يۇرۇقلۇقى",
    "Contrast" : "سېلىشتۇرما",
    "Un-flip X" : "Un-flip X.",
    "Flip X" : "Flip X.",
    "Un-flip Y" : "Un-flip Y.",
    "Flip Y" : "Flip Y.",
    "HSV" : "HSV",
    "Hue" : "Hue",
    "Saturation" : "قېنىقلىقى",
    "Value" : "قىممەت",
    "Image" : "رەسىم",
    "Importing …" : "كىرگۈزۋاتىدۇ ...",
    "+ Add image" : "+ رەسىم قوشۇڭ",
    "Upload image" : "رەسىم يوللاش",
    "From gallery" : "رەسىم ئامبىرىدىن",
    "Line" : "قۇر",
    "Pen" : "قەلەم",
    "Polygon" : "كۆپ گۈللۈك",
    "Sides" : "يان تەرەپ",
    "Rectangle" : "تىك تۆت بۇلۇڭ",
    "Corner Radius" : "بۇلۇڭ رادىئۇسى",
    "Width in pixels" : "پىكسېلنىڭ كەڭلىكى",
    "Height in pixels" : "پېكسىل ئېگىزلىكى",
    "Toggle ratio lock" : "نىسبىتىنى قۇلۇپلاش",
    "Reset to original image size" : "ئەسلى رەسىم چوڭلۇقىغا قايتۇرۇڭ",
    "Rotate" : "ئايلاندۇرۇش",
    "Text" : "تېكىست",
    "Text spacing" : "تېكىست ئارىلىقى",
    "Text alignment" : "تېكىستنى توغرىلاش",
    "Font family" : "خەت نۇسخىسى ئائىلىسى",
    "Size" : "چوڭلۇقى",
    "Letter spacing" : "خەت ئارىلىقى",
    "Line height" : "سىزىق ئېگىزلىكى",
    "Warmth" : "قىزغىن",
    "+ Add watermark" : "+ سۇ بەلگىسى قوشۇڭ",
    "+ Add text watermark" : "+ تېكىست سۇ بەلگىسىنى قوشۇڭ",
    "Choose watermark type" : "سۇ بەلگىسى تۈرىنى تاللاڭ",
    "Upload watermark" : "سۇ بەلگىسىنى يۈكلەڭ",
    "Add as text" : "تېكىست سۈپىتىدە قوشۇڭ",
    "Padding" : "ئارلىق",
    "Paddings" : "ئارلىقلار",
    "Shadow" : "سايە",
    "Horizontal" : "توغرىسىغا",
    "Vertical" : "ۋېرتىكال",
    "Opacity" : "تۇتۇقلۇقى",
    "Transparency" : "نۇر ئۆتكۈزۈشچانلىقى",
    "Position" : "ئورنى",
    "Stroke" : "سەكتە",
    "Save image as" : "رەسىمنى ساقلاڭ",
    "Extension" : "كېڭەيتىش",
    "Format" : "فورماتى",
    "Name is required." : "ئىسىم تەلەپ قىلىنىدۇ.",
    "Quality" : "سۈپەت",
    "Saved image size (width x height)" : "ساقلانغان رەسىم چوڭلۇقى (كەڭلىكى x ئېگىزلىكى)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "شۇنىڭغا دىققەت قىلىڭكى ، تاللانغان زىرائەت رايونى قوللىنىلغان ئۆلچەمدىن تۆۋەن بولۇپ ، سۈپەتنىڭ تۆۋەنلىشىنى كەلتۈرۈپ چىقىرىشى مۇمكىن",
    "Actual size (100%)" : "ئەمەلىي چوڭلۇقى (%100)",
    "Fit size" : "ماس كېلىدىغان چوڭلۇقى",
    "Select image to add …" : "قوشۇش ئۈچۈن رەسىم تاللاڭ…",
    "Failed to load image." : "رەسىم يۈكلەنمىدى.",
    "Menu" : "تىزىملىك",
    "Width" : "كەڭلىك",
    "Height" : "ئېگىزلىكى",
    "No preview available for this crop item" : "بۇ زىرائەت تۈرىگە ئالدىن كۆزىتىش يوق"
},
"nplurals=2; plural=(n != 1);");
